# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.3.0] - 1980-01-01

- :warning: require C++ >= 14
- setup nix packaging & CI
- setup mergify
- Only add GCC Clang warnings options in GCC/Clang
- update for jrl-cmakemodules v1

## [1.2.9] - 2024-08-26

- allow use of installed jrl-cmakemodules
- setup ROS CI

## [1.2.8] - 2023-11-29

- added CHANGELOG

## [1.2.7] - 2023-11-15

- Respect BUILD_SHARED_LIBS
- Update CMake

## [1.2.6] - 2023-03-31

- Adding inline keyword on (deprecated) solve_eiquadprog2 implemented in header
- Ignore Wsign-conversion warnings

## [1.2.5] - 2022-09-12

- fix trace solver


## [1.2.4] - 2022-09-05

- tests are now optional
- Remove memory allocations and expose dual variables to the user
- fix warning about cast of unused parameters
- modernize CMake
- update tools & badges
- reformat


## [1.2.3] - 2021-03-10

Maintenance release

## [1.2.2] - 2020-09-21

- Update package.xml for ROS release

## [1.2.1] - 2020-09-09

- add TRACE_SOLVER option
- fix packaging

## [1.2.0] - 2020-05-26

- add a shared library

## [1.1.3] - 2020-03-24

- CMake: export project and use exports from dependencies
- CMake: keep minimal required instructions

## [1.1.2] - 2020-03-11

- fix build on 16.04, where Eigen3Config.cmake doesn't provide a version

## [1.1.1] - 2020-03-11

- update README

## [1.1.0] - 2020-03-11

- Added CMake Export

## [1.0.0] - 2019-10-24

- Add eiquadprog-rt
- Fix license
- Configure CI
- Reformat
- update CMake

## [0.0.3] - 2019-10-08

Initial Release

[Unreleased]: https://github.com/stack-of-tasks/eiquadprog/compare/v1.3.0...HEAD
[1.3.0]: https://github.com/stack-of-tasks/eiquadprog/compare/v1.2.9...v1.3.0
[1.2.9]: https://github.com/stack-of-tasks/eiquadprog/compare/v1.2.8...v1.2.9
[1.2.8]: https://github.com/stack-of-tasks/eiquadprog/v1.2.7...v1.2.8
[1.2.7]: https://github.com/stack-of-tasks/eiquadprog/v1.2.6...v1.2.7
[1.2.6]: https://github.com/stack-of-tasks/eiquadprog/v1.2.5...v1.2.6
[1.2.5]: https://github.com/stack-of-tasks/eiquadprog/v1.2.4...v1.2.5
[1.2.4]: https://github.com/stack-of-tasks/eiquadprog/v1.2.3...v1.2.4
[1.2.3]: https://github.com/stack-of-tasks/eiquadprog/v1.2.2...v1.2.3
[1.2.2]: https://github.com/stack-of-tasks/eiquadprog/v1.2.1...v1.2.2
[1.2.1]: https://github.com/stack-of-tasks/eiquadprog/v1.2.0...v1.2.1
[1.2.0]: https://github.com/stack-of-tasks/eiquadprog/v1.1.3...v1.2.0
[1.1.3]: https://github.com/stack-of-tasks/eiquadprog/v1.1.2...v1.1.3
[1.1.2]: https://github.com/stack-of-tasks/eiquadprog/v1.1.1...v1.1.2
[1.1.1]: https://github.com/stack-of-tasks/eiquadprog/v1.1.0...v1.1.1
[1.1.0]: https://github.com/stack-of-tasks/eiquadprog/v1.0.0...v1.1.0
[1.0.0]: https://github.com/stack-of-tasks/eiquadprog/v0.0.3...v1.0.0
[0.0.3]: https://github.com/stack-of-tasks/eiquadprog/releases/tag/v0.0.3
